#!/usr/bin/env python
#
# __main__.py
#

import sys
import kamidana.commands.onefile as kamidana
from argparse import ArgumentParser
from . import __version__ as VERSION


def main():
    parser = ArgumentParser(add_help=False)
    parser.add_argument(
        '-v',
        '--version',
        action='version',
        version=u'%(prog)s version ' + VERSION
    )
    opts, args = parser.parse_known_args()
    sys.argv = ['kamidana'] + args + ['-a=amaterasu.amaterasu', '-a=amaterasu.utils']
    kamidana.main()


if __name__ == '__main__':
    main()



#!/usr/bin/env python
#
# amaterasu.py
#

from kamidana import (
    as_filter,
    as_global,
    # as_globals_generator,
    # as_test,
)

from wandbox.wrapper import Wrapper as Wandbox
import fnmatch

w = Wandbox()


def get_compiler_list():
    return w.get_compiler_list(1, 10)


@as_global
def wandbox_list():
    return get_compiler_list()


@as_global
def wandbox_languages():
    r = get_compiler_list()
    langs = map(lambda x: x['language'], r)
    return sorted(set(langs))


@as_filter
def wandbox_fnmatch_compilers(v, m):
    result = []
    for d in v:
        if fnmatch.fnmatch(d['name'], m):
            result.append(d)
    return result


@as_filter
def wandbox_language_compilers(v, lang):
    result = []
    for d in v:
        if d['language'] == lang:
            result.append(d)
    return result



#!/usr/bin/env python
#
# amaterasu.py
#

from kamidana import (
    as_filter,
    # as_global,
    # as_globals_generator,
    # as_test,
)

import urllib.parse
import re


@as_filter
def markdown_link_pair(v):
    cache = {}
    result = []
    for name in v:
        link = name
        link = link.replace(' ', '-')
        link = re.sub('[!@#$+]', '', link)
        if link in cache:
            cache[link] += 1
            link = '{0}-{1}'.format(link, cache[link])
        else:
            cache[link] = 0
        result.append({"name": name, "link": link})
    return result


@as_filter
def urlencode(v):
    return urllib.parse.urlencode(v)


@as_filter
def url_quote(v, safe=''):
    return urllib.parse.quote(v, safe=safe)


@as_filter
def url_quote_plus(v, safe=''):
    return urllib.parse.quote_plus(v, safe=safe)


@as_filter
def replace_url_quote(v):
    return v.replace('%23', '%2523').replace('%20', '%2520')



import os
import re
from setuptools import setup

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

f = open(os.path.join(os.path.dirname(__file__), 'amaterasu/__init__.py'))
for line in f:
    if '__version__ = ' in line:
        version_ = [x for x in re.split(r"[ =']", line) if x][1]
    elif '__author__ = ' in line:
        author_ = [x for x in re.split(r"[ =']", line) if x][1]
f.close()

test_deps = ['importlib-metadata<2,>=0.12', 'tox', 'pytest']

setup(
    name = "amaterasu-j2"
    , version = version_
    , author = author_
    , author_email = "zumix.cpp@gmail.com"
    , url = "https://github.com/srz-zumix/amaterasu/"
    , description = "Wandbox API Jinja2 template cli."
    , license = "MIT"
    , platforms = ["any"]
    , keywords = "jinja2, cli, kamidana, Wandbox"
    , packages = ['amaterasu']
    , long_description = readme
    , long_description_content_type='text/markdown'
    , classifiers = [
        "Development Status :: 4 - Beta"
        , "Topic :: Utilities"
        , "License :: OSI Approved :: MIT License"
        , "Programming Language :: Python"
        , "Programming Language :: Python :: 3.7"
        , "Programming Language :: Python :: 3.8"
        , "Programming Language :: Python :: 3.9"
    ]
    , entry_points={
        'console_scripts': [
            'amaterasu = amaterasu.__main__:main'
        ]
    }
    , install_requires=['requests', 'pyyaml', 'wandbox-api >= 0.9.28', 'kamidana']
    , tests_require=test_deps
    , test_suite="tests.test_suite"
    , extras_require={
        'test': test_deps
    }
)
